<?php
/**
 * Registers all block assets so that they can be enqueued through the block editor
 * in the corresponding context.
 *
 * @see https://developer.wordpress.org/block-editor/tutorials/block-tutorial/applying-styles-with-stylesheets/
 */

if (!function_exists('wptools_blocks_faq_list_block_init')) {
    function wptools_blocks_faq_list_block_init() {
        $container = \WPT\FaqManager\Loader::getInstance(); // added
        $dir       = dirname(__FILE__);

        $script_asset_path = "$dir/build/index.asset.php";
        if (!file_exists($script_asset_path)) {
            throw new Error(
                'You need to run `npm start` or `npm run build` for the "wptools-block/faq-list" block first.'
            );
        }
        $index_js     = 'build/index.js';
        $script_asset = require $script_asset_path;
        wp_register_script(
            'wptools-block-faq-list-block-editor',
            plugins_url($index_js, __FILE__),
            ['wp-blocks', 'wp-element', 'wp-components', 'wp-editor', 'wp-i18n', 'wp-polyfill'], //this changed
            $script_asset['version']
        );

        $editor_css = 'editor.css';
        wp_register_style(
            'wptools-block-faq-list-block-editor',
            plugins_url($editor_css, __FILE__),
            [],
            filemtime("$dir/$editor_css")
        );

        $attributes = new \WPT\FaqManager\Blocks\FaqList\Attributes();

        register_block_type('wptools-block/faq-list', [
            'render_callback' => [$container['faq_list_block'], 'render_callback'], //this is added
            'editor_script'   => 'wptools-block-faq-list-block-editor',
            'editor_style'    => 'wptools-block-faq-list-block-editor',
            'style'           => 'wptools-block-faq-list-block',
            'attributes'      => $attributes->get_attributes(),
        ]);
    }
}

add_action('init', 'wptools_blocks_faq_list_block_init');
