<?php
namespace WPT\FaqManager\Blocks\FaqList;

use WPT\FaqManager\Blocks\Styles\GoogleFonts;
use WPT\FaqManager\Blocks\Styles\CssVariables;

/**
 * Block.
 */
class Block {
    protected $container;

    /**
     * Constructor.
     */
    public function __construct($container) {
        $this->container = $container;
    }

    public function render_callback($attributes, $content) {
        $selector = sprintf('div.wpt-faq-accordion#%s', $attributes['cssId']);

        $cssVariables = new CssVariables($attributes, 'wpt-faq', $selector);
        $cssVariables->addAttributesDefinition((new Attributes())->get_attributes());

        $cssVariables->addSingleValue('tg-icon-stroke-open', 'icon_color_open')
            ->addSingleValue('tg-icon-fill-open', 'icon_color_open')
            ->addSingleValue('tg-icon-stroke-close', 'icon_color_close')
            ->addSpacing('category-m', 'categoryTitleMargin')
            ->addSpacing('category-p', 'categoryTitlePadding')
            ->addTypography('category', 'categoryTitleTypography')
            ->addSpacing('tg-ul-margin', 'faqListWrapperMargin', false)
            ->addSpacing('tg-ul-padding', 'faqListWrapperPadding')
            ->addBorder('tg-ul', 'faqListWrapperBorder')
            ->addSpacing('tg-item-margin', 'faqItemMargin')
            ->addSpacing('tg-item-padding', 'faqItemPadding')
            ->addBorder('tg-item', 'faqItemBorder')
            ->addSpacing('tg-question-m', 'questionMargin')
            ->addSpacing('tg-question-p', 'questionPadding')
            ->addBorder('tg-question', 'questionBorder')
            ->addTypography('tg-question', 'questionTypography')
            ->addSpacing('tg-ans-m', 'answerMargin')
            ->addSpacing('tg-ans-p', 'answerPadding')
            ->addSingleValue('tg-icon-fill-close', 'icon_color_close');

        $inlineCss = $cssVariables->getStyles();

        $shortcode = sprintf(
            '[wpt_faqs filter_by_categories="%1$s" group_by_categories="%2$s" categories="%3$s" post__in="%4$s" post__not_in="%5$s" faqs_per_page="%6$d" orderby="%7$s" order="%8$s" expand="%9$s" can_open="%10$s" icon_placement="%11$s" icon_set="%12$s" css_id="%13$s" css_classes="%14$s" category_name_html_tag="%15$s"/]',
            $attributes['filterByCategories'] ? '1' : '0',
            $attributes['groupByCategories'] ? '1' : '0',
            implode(',', $attributes['categories']),
            $attributes['post__in'],
            $attributes['post__not_in'],
            $attributes['faqs_per_page'],
            $attributes['orderby'],
            $attributes['order'],
            $attributes['expand'] ? '1' : '0',
            $attributes['can_open'],
            $attributes['icon_placement'],
            $attributes['icon_set'],
            $attributes['cssId'],
            $attributes['className'],
            $attributes['category_name_html_tag']
        );
        // return $shortcode;
        $html = do_shortcode($shortcode);

        if (isset($_GET['context']) and ($_GET['context'] == 'edit')) {
            return sprintf("%s<style>%s</style>", $html, $inlineCss);
        }

        wp_register_style('wpt-faq-manager-faq-list-block-inline-css', false);
        wp_enqueue_style('wpt-faq-manager-faq-list-block-inline-css');
        wp_add_inline_style('wpt-faq-manager-faq-list-block-inline-css', $inlineCss);

        if ($attributes['loadGoogleFonts']) {
            GoogleFonts::importFonts('wpt-faq-manager-faq-list-block-inline-css');
        }

        return $html;
    }

}
