<?php
namespace WPT\FaqManager\Divi\Components;
/**
 * Border field.
 */
class Border {

    public function get_border_fields($prefix, $tab_slug, $toggle_slug, $default) {
        $fields = [];

        $default = explode('|', $default);

        $fields[$prefix . '_border_top'] = [
            'label'          => esc_html__('Border Top', 'et_builder'),
            'type'           => 'range',
            'range_settings' => [
                'min'  => 0,
                'max'  => 100,
                'step' => 1,
            ],
            'tab_slug'       => $tab_slug,
            'toggle_slug'    => $toggle_slug,
            'allowed_units'  => ['px'],
            'default_unit'   => 'px',
            'default'        => $default[0],
        ];

        $fields[$prefix . '_border_right'] = [
            'label'          => esc_html__('Border Right', 'et_builder'),
            'type'           => 'range',
            'range_settings' => [
                'min'  => 0,
                'max'  => 100,
                'step' => 1,
            ],
            'tab_slug'       => $tab_slug,
            'toggle_slug'    => $toggle_slug,
            'allowed_units'  => ['px'],
            'default_unit'   => 'px',
            'default'        => $default[1],
        ];

        $fields[$prefix . '_border_bottom'] = [
            'label'          => esc_html__('Border Bottom', 'et_builder'),
            'type'           => 'range',
            'range_settings' => [
                'min'  => 0,
                'max'  => 100,
                'step' => 1,
            ],
            'tab_slug'       => $tab_slug,
            'toggle_slug'    => $toggle_slug,
            'allowed_units'  => ['px'],
            'default_unit'   => '',
            'default'        => $default[2],
        ];

        $fields[$prefix . '_border_left'] = [
            'label'          => esc_html__('Border Left', 'et_builder'),
            'type'           => 'range',
            'range_settings' => [
                'min'  => 0,
                'max'  => 100,
                'step' => 1,
            ],
            'tab_slug'       => $tab_slug,
            'toggle_slug'    => $toggle_slug,
            'allowed_units'  => ['px'],
            'default_unit'   => '',
            'default'        => $default[3],
        ];

        $fields[$prefix . '_border_color'] = [
            'label'       => esc_html__('Border Color', 'et_builder'),
            'type'        => 'color-alpha',
            'tab_slug'    => $tab_slug,
            'toggle_slug' => $toggle_slug,
            'default'     => $default[4],
        ];

        $fields[$prefix . '_border_style'] = [
            'label'       => esc_html__('Border Style', 'et_builder'),
            'type'        => 'select',
            'options'     => [
                'none'    => 'None',
                'hidden'  => 'Hidden',
                'dotted'  => 'Dotted',
                'dashed'  => 'Dashed',
                'solid'   => 'Solid',
                'double'  => 'Double',
                'groove'  => 'Groove',
                'ridge'   => 'Ridge',
                'inset'   => 'Inset',
                'outset'  => 'Outset',
                'initial' => 'Initial',
                'inherit' => 'Inherit',
            ],
            'tab_slug'    => $tab_slug,
            'toggle_slug' => $toggle_slug,
            'description' => esc_html__('', 'et_builder'),
            'default'     => $default[5],
        ];

        return $fields;

    }

    public function get_css_variables($props, $props_prefix, $css_variable_prefix) {
        $css_vars = [];
        if (isset($props[$props_prefix . '_border_top'])) {
            $css_vars[$css_variable_prefix . '-top-bw'] = $props[$props_prefix . '_border_top'];
        }
        if (isset($props[$props_prefix . '_border_right'])) {
            $css_vars[$css_variable_prefix . '-right-bw'] = $props[$props_prefix . '_border_right'];
        }
        if (isset($props[$props_prefix . '_border_bottom'])) {
            $css_vars[$css_variable_prefix . '-bottom-bw'] = $props[$props_prefix . '_border_bottom'];
        }
        if (isset($props[$props_prefix . '_border_left'])) {
            $css_vars[$css_variable_prefix . '-left-bw'] = $props[$props_prefix . '_border_left'];
        }
        if (isset($props[$props_prefix . '_border_color'])) {
            $css_vars[$css_variable_prefix . '-bc'] = $props[$props_prefix . '_border_color'];
        }
        if (isset($props[$props_prefix . '_border_style'])) {
            $css_vars[$css_variable_prefix . '-bs'] = $props[$props_prefix . '_border_style'];
        }
        return $css_vars;
    }
}
