<?php

namespace WPT\FaqManager\WP\PostType;

/**
 * Faq.
 */
class Faq
{
    protected  $container ;
    /**
     * Constructor.
     */
    public function __construct( $container )
    {
        $this->container = $container;
    }
    
    /**
     * Structured data for faqs
     */
    public function get_structured_data( $faqs )
    {
        global  $post ;
        if ( isset( $faqs->ID ) ) {
            $faqs = [ $faqs ];
        }
        $data = [
            '@context'   => 'http://schema.org',
            '@type'      => 'FAQPage',
            'mainEntity' => [],
        ];
        foreach ( $faqs as $faq ) {
            $answer_type = (object) [
                '@type' => 'Answer',
                'text'  => apply_filters( 'the_content', $faq->post_content ),
            ];
            $data['mainEntity'][] = [
                '@type'          => 'Question',
                'name'           => $faq->post_title,
                'url'            => get_the_permalink( $post ) . '#faq-item-' . sanitize_title( $faq->post_title ),
                'answerCount'    => 1,
                'acceptedAnswer' => $answer_type,
            ];
        }
        echo  '<script type="application/ld+json">' . json_encode( (object) $data ) . '</script>' ;
    }
    
    /**
     * Get the faqs based on the conditions
     */
    public function get_faqs( $attrs )
    {
        $args = [
            'post_type'      => 'wpt-faq',
            'post_status'    => 'publish',
            'posts_per_page' => (int) $attrs['faqs_per_page'],
            'orderby'        => $attrs['orderby'],
            'order'          => $attrs['order'],
        ];
        if ( fs_wpt_faq()->is_free_plan() ) {
            if ( $args['orderby'] == 'menu_order' ) {
                $args['orderby'] = 'date';
            }
        }
        $faq_query = new \WP_Query( $args );
        $faqs = $faq_query->get_posts();
        $faq_chunks = [];
        $terms = [
            '-1' => 'free',
        ];
        $faq_chunks['-1'] = $faqs;
        return [ $faq_chunks, $terms, count( $faqs ) ];
    }

}