<?php

namespace WPT\FaqManager\WP\Shortcodes;

/**
 * FaqAccordion.
 */
class FaqAccordion
{
    protected  $container ;
    /**
     * counter to the number of faq shortcodes on the page.
     */
    public static  $count = 0 ;
    /**
     * Constructor.
     */
    public function __construct( $container )
    {
        $this->container = $container;
    }
    
    public function render( $attrs )
    {
        self::$count++;
        global  $post ;
        $attrs = shortcode_atts( $this->default_shortcode_atts(), $attrs );
        list( $faq_chunks, $terms, $faq_count ) = $this->container['faq_post_type']->get_faqs( $attrs );
        $categories = [ "-1" ];
        $this->enqueue_assets();
        $custom_css = sprintf( '#%s.wpt-faq-accordion {%s}', $attrs['css_id'], $this->get_custom_css( $attrs ) );
        wp_add_inline_style( 'wpt-faq-accordion-style', $custom_css );
        if ( $attrs['expand'] ) {
            $attrs['can_open'] = 'many';
        }
        $svn_icon_html = $this->get_icon_set( $attrs['icon_set'] );
        $all_faqs = [];
        ob_start();
        require $this->container['plugin_dir'] . '/resources/views/shortcodes/accordion.php';
        return ob_get_clean();
    }
    
    public function get_custom_css( $attrs )
    {
        $css = '';
        $vars = [
            '--wpt-faq-tg-icon-stroke-open'  => $attrs['icon_color_open'],
            '--wpt-faq-tg-icon-fill-open'    => $attrs['icon_color_open'],
            '--wpt-faq-tg-icon-stroke-close' => $attrs['icon_color_close'],
            '--wpt-faq-tg-icon-fill-close'   => $attrs['icon_color_close'],
            '--wpt-faq-tg-question-c-open'   => $attrs['question_text_color_open'],
            '--wpt-faq-tg-question-c'        => $attrs['question_text_color_close'],
        ];
        foreach ( $vars as $key => $value ) {
            $css .= sprintf( "%s : %s;\n", $key, $value );
        }
        return $css;
    }
    
    public function get_icon_set( $name )
    {
        switch ( $name ) {
            case 'plus-minus':
                $icon = new Icons\PlusMinus();
                break;
            default:
                $icon = new Icons\PlusMinus();
                break;
        }
        return $icon->svg();
    }
    
    public function default_shortcode_atts()
    {
        $defaults = [
            'faqs_per_page'             => -1,
            'orderby'                   => 'date',
            'order'                     => 'ASC',
            'css_id'                    => 'wpt-faqs',
            'css_classes'               => '',
            'expand'                    => '0',
            'update_browser_url'        => '1',
            'can_open'                  => 'one',
            'icon_placement'            => 'left',
            'icon_set'                  => 'plus-minus',
            'style_preset'              => 'default',
            'icon_color_open'           => '#4c8bf5',
            'icon_color_close'          => '#4c8bf5',
            'question_text_color_close' => '#2f3b48',
            'question_text_color_open'  => '#4c8bf5',
        ];
        return $defaults;
    }
    
    public function enqueue_assets()
    {
        wp_enqueue_script( 'jquery' );
        wp_enqueue_script(
            'wpt-faq-accordion-js',
            $this->container['plugin_url'] . '/js/faq-accordion/script.js',
            [ 'jquery' ],
            $this->container['plugin_version']
        );
        $this->enqueue_styles();
    }
    
    public function enqueue_styles()
    {
        wp_register_style( 'wpt-faq-accordion-placeholder', false );
        wp_enqueue_style( 'wpt-faq-accordion-placeholder' );
        wp_enqueue_style( 'wpt-faq-accordion-style', $this->container['plugin_url'] . '/styles/faq-accordion/style.css', [ 'wpt-faq-accordion-placeholder' ] );
    }

}