<?php

/**
 * Registers the `wpt_faq` post type.
 */

if ( !function_exists( 'wpt_faq_init' ) ) {
    function wpt_faq_init()
    {
        $loader = \WPT\FaqManager\Loader::getInstance();
        $supports = [ 'title', 'editor' ];
        register_post_type( 'wpt-faq', [
            'labels'                => [
            'name'                  => __( 'FAQs', 'faq-manager-with-structured-data' ),
            'singular_name'         => __( 'FAQ', 'faq-manager-with-structured-data' ),
            'all_items'             => __( 'All FAQs', 'faq-manager-with-structured-data' ),
            'archives'              => __( 'FAQ Archives', 'faq-manager-with-structured-data' ),
            'attributes'            => __( 'FAQ Attributes', 'faq-manager-with-structured-data' ),
            'insert_into_item'      => __( 'Insert into FAQ', 'faq-manager-with-structured-data' ),
            'uploaded_to_this_item' => __( 'Uploaded to this FAQ', 'faq-manager-with-structured-data' ),
            'featured_image'        => _x( 'Featured Image', 'wpt-faq', 'faq-manager-with-structured-data' ),
            'set_featured_image'    => _x( 'Set featured image', 'wpt-faq', 'faq-manager-with-structured-data' ),
            'remove_featured_image' => _x( 'Remove featured image', 'wpt-faq', 'faq-manager-with-structured-data' ),
            'use_featured_image'    => _x( 'Use as featured image', 'wpt-faq', 'faq-manager-with-structured-data' ),
            'filter_items_list'     => __( 'Filter FAQs list', 'faq-manager-with-structured-data' ),
            'items_list_navigation' => __( 'FAQs list navigation', 'faq-manager-with-structured-data' ),
            'items_list'            => __( 'FAQs list', 'faq-manager-with-structured-data' ),
            'new_item'              => __( 'New FAQ', 'faq-manager-with-structured-data' ),
            'add_new'               => __( 'Add New', 'faq-manager-with-structured-data' ),
            'add_new_item'          => __( 'Add New FAQ', 'faq-manager-with-structured-data' ),
            'edit_item'             => __( 'Edit FAQ', 'faq-manager-with-structured-data' ),
            'view_item'             => __( 'View FAQ', 'faq-manager-with-structured-data' ),
            'view_items'            => __( 'View FAQs', 'faq-manager-with-structured-data' ),
            'search_items'          => __( 'Search FAQs', 'faq-manager-with-structured-data' ),
            'not_found'             => __( 'No FAQs found', 'faq-manager-with-structured-data' ),
            'not_found_in_trash'    => __( 'No FAQs found in trash', 'faq-manager-with-structured-data' ),
            'parent_item_colon'     => __( 'Parent FAQ:', 'faq-manager-with-structured-data' ),
            'menu_name'             => __( 'FAQs', 'faq-manager-with-structured-data' ),
        ],
            'public'                => false,
            'hierarchical'          => false,
            'show_ui'               => true,
            'show_in_nav_menus'     => true,
            'supports'              => $supports,
            'has_archive'           => false,
            'rewrite'               => false,
            'query_var'             => true,
            'menu_position'         => null,
            'menu_icon'             => $loader['plugin_url'] . '/images/faq-icon.png',
            'show_in_rest'          => true,
            'rest_base'             => 'wpt-faq',
            'rest_controller_class' => 'WP_REST_Posts_Controller',
        ] );
    }
    
    add_action( 'init', 'wpt_faq_init' );
}


if ( !function_exists( 'wpt_faq_updated_messages' ) ) {
    function wpt_faq_updated_messages( $messages )
    {
        global  $post ;
        $permalink = get_permalink( $post );
        $messages['wpt-faq'] = [
            0  => '',
            1  => sprintf( __( 'FAQ updated. <a target="_blank" href="%s">View FAQ</a>', 'faq-manager-with-structured-data' ), esc_url( $permalink ) ),
            2  => __( 'Custom field updated.', 'faq-manager-with-structured-data' ),
            3  => __( 'Custom field deleted.', 'faq-manager-with-structured-data' ),
            4  => __( 'FAQ updated.', 'faq-manager-with-structured-data' ),
            5  => ( isset( $_GET['revision'] ) ? sprintf( __( 'FAQ restored to revision from %s', 'faq-manager-with-structured-data' ), wp_post_revision_title( (int) $_GET['revision'], false ) ) : false ),
            6  => sprintf( __( 'FAQ published. <a href="%s">View FAQ</a>', 'faq-manager-with-structured-data' ), esc_url( $permalink ) ),
            7  => __( 'FAQ saved.', 'faq-manager-with-structured-data' ),
            8  => sprintf( __( 'FAQ submitted. <a target="_blank" href="%s">Preview FAQ</a>', 'faq-manager-with-structured-data' ), esc_url( add_query_arg( 'preview', 'true', $permalink ) ) ),
            9  => sprintf( __( 'FAQ scheduled for: <strong>%1$s</strong>. <a target="_blank" href="%2$s">Preview FAQ</a>', 'faq-manager-with-structured-data' ), date_i18n( __( 'M j, Y @ G:i', 'faq-manager-with-structured-data' ), strtotime( $post->post_date ) ), esc_url( $permalink ) ),
            10 => sprintf( __( 'FAQ draft updated. <a target="_blank" href="%s">Preview FAQ</a>', 'faq-manager-with-structured-data' ), esc_url( add_query_arg( 'preview', 'true', $permalink ) ) ),
        ];
        return $messages;
    }
    
    add_filter( 'post_updated_messages', 'wpt_faq_updated_messages' );
}
